@@ -91,7 +91,7 @@ def test_scramble_writing_job(client, metadata_client, csv_items):
 
 
 @pytest.mark.local
-def test_scramble_reading_job(client, metadata_client, csv_items):
+def test_scramble_reading_job(client, metadata_client):
     job_params = {
         'job_name': TEST_JOB_NAME,
         'reader_name': 'CsvReader',
@@ -105,10 +105,9 @@ def test_scramble_reading_job(client, metadata_client, csv_items):
         json=metadata_client
     )
     assert response.status_code == 200, response.text
-    n_items = len(csv_items)
+    n_items = 10
     response = client.post(
-        f'/serve?job_name={TEST_JOB_NAME}&batch_size={n_items}',
-        json=csv_items
+        f'/serve?job_name={TEST_JOB_NAME}&batch_size={n_items}'
     )
     assert response.status_code == 200, response.text
     items = json.loads(response.text)
@@ -120,6 +119,53 @@ def test_scramble_reading_job(client, metadata_client, csv_items):
     assert response.status_code == 400, response.text
 
 
+@pytest.mark.local
+def test_scramble_cont_job(client, metadata_client):
+    # start a new job
+    job_params = {
+        'job_name': TEST_JOB_NAME,
+        'reader_name': 'CsvReader',
+        'writer_name': 'CsvWriter',
+        'clean_start': 'false',
+        'cont': False
+    }
+    param_string = _make_param_string(job_params)
+    response = client.post(
+        f'/scramble?{param_string}',
+        json=metadata_client
+    )
+    assert response.status_code == 200, response.text
+    # serve some items
+    n_served = 10
+    n_received = 5
+    response = client.post(
+        f'/serve?job_name={TEST_JOB_NAME}&batch_size={n_served}'
+    )
+    assert response.status_code == 200, response.text
+    items = json.loads(response.text)
+    assert len(items) == n_served
+    # send back some of the "processed" items
+    response = client.post(
+        f'/receive?job_name={TEST_JOB_NAME}&overwrite=false',
+        json=items[:n_received]
+    )
+    assert response.status_code == 200, response.text
+    # make a continuation job
+    job_params['cont'] = True
+    param_string = _make_param_string(job_params)
+    response = client.post(
+        f'/scramble?{param_string}',
+        json=metadata_client
+    )
+    assert response.status_code == 200, response.text
+    # generating a report
+    response = client.get(f'/report?job_name={TEST_JOB_NAME}')
+    assert response.status_code == 200, response.text
+    report = json.loads(response.text)
+    assert report['served'] == 0
+    assert report['received'] == n_received
+
+
 @pytest.mark.local
 def test_receive(client, job_params, metadata):
     param_string = _make_param_string(job_params)
@@ -210,3 +256,31 @@ def test_mark_errors_receive(client, job_params, metadata):
         json=ids
     )
     assert response.status_code == 400, response.text
+
+
+@pytest.mark.local
+def test_clean(client, job_params, metadata):
+    n_served = 10
+    n_received = 5
+    param_string = _make_param_string(job_params)
+    client.post(
+        f'/scramble?{param_string}',
+        json=metadata
+    )
+    items = json.loads(
+        client.post(f'/serve?job_name={TEST_JOB_NAME}&'
+                    f'batch_size={n_served}').text
+    )
+    response = client.post(
+        f'/receive?job_name={TEST_JOB_NAME}&overwrite=false',
+        json=items[:n_received]
+    )
+    assert response.status_code == 200, response.text
+    response = client.get(f'/clean?job_name={TEST_JOB_NAME}')
+    assert response.status_code == 200, response.text
+    response = client.get(f'/report?job_name={TEST_JOB_NAME}')
+    assert response.status_code == 200, response.text
+    report = json.loads(response.text)
+    assert report['served'] == 0
+    assert report['received'] == n_received
+
